Learn R Programming

fastbioclim (version 0.3.0)

bionames: Print Bioclimatic Variable Names

Description

This function prints the names of bioclimatic variables based on the specified indices.

Usage

bionames(bios = 1:35)

Value

None. Prints the names of the selected bioclimatic variables to the console.

Arguments

bios

Numeric vector indicating the indices of bioclimatic variables to print. Default is 1:35, which prints all variable names.

Examples

Run this code
bionames()           # Print all bioclimatic variable names
bionames(c(1, 5, 12)) # Print names for variables 1, 5, and 12

Run the code above in your browser using DataLab