powered by
This function prints the names of bioclimatic variables based on the specified indices.
bionames(bios = 1:35)
None. Prints the names of the selected bioclimatic variables to the console.
Numeric vector indicating the indices of bioclimatic variables to print. Default is 1:35, which prints all variable names.
bionames() # Print all bioclimatic variable names bionames(c(1, 5, 12)) # Print names for variables 1, 5, and 12
Run the code above in your browser using DataLab